From 6d1b81d57b205d53c305d31332a017810c46bdc8 Mon Sep 17 00:00:00 2001
From: Joe R <joeraz5@verizon.net>
Date: Wed, 31 Jan 2024 20:33:39 -0500
Subject: [PATCH] Take away is a golf type game, and other organization fixes.

---
 contrib/help-pages-translation-to-french/gen-html.py | 1 -
 pysollib/games/takeaway.py                           | 6 +++---
 scripts/all_games.py                                 | 1 -
 3 files changed, 3 insertions(+), 5 deletions(-)

diff --git a/contrib/help-pages-translation-to-french/gen-html.py b/contrib/help-pages-translation-to-french/gen-html.py
index f52fb801..387a5626 100755
--- a/contrib/help-pages-translation-to-french/gen-html.py
+++ b/contrib/help-pages-translation-to-french/gen-html.py
@@ -18,7 +18,6 @@ builtins.n_ = lambda x: x
 import pysollib.games  # noqa: E402,F402,I100,I202
 import pysollib.games.mahjongg  # noqa: E402,F402
 import pysollib.games.special  # noqa: E402,F401,F402
-import pysollib.games.ultra  # noqa: E402,F401,F402
 
 try:
     os.mkdir('html')
diff --git a/scripts/all_games.py b/scripts/all_games.py
index 153f0396..36f98c41 100755
--- a/scripts/all_games.py
+++ b/scripts/all_games.py
@@ -10,7 +10,6 @@ import time
 import pysollib.games
 import pysollib.games.mahjongg  # noqa: F401
 import pysollib.games.special
-import pysollib.games.ultra  # noqa: F401
 from pysollib.gamedb import GAME_DB
 from pysollib.gamedb import GI
 from pysollib.mfxutil import latin1_normalize
diff --git a/pysollib/games/takeaway.py b/pysollib/games/takeaway.py
index c4081e4a..fc274109 100644
--- a/pysollib/games/takeaway.py
+++ b/pysollib/games/takeaway.py
@@ -242,11 +242,11 @@ class TakeAway8(TakeAway):
 
 # register the game
 registerGame(GameInfo(334, TakeAway, "Take Away",
                       GI.GT_1DECK_TYPE | GI.GT_OPEN, 1, 0, GI.SL_MOSTLY_SKILL,
                       altnames=("Eliminator", "Wolfpack", "Strip")))
 registerGame(GameInfo(335, FourStacks, "Four Stacks",
                       GI.GT_1DECK_TYPE | GI.GT_OPEN, 1, 0, GI.SL_MOSTLY_SKILL))
 registerGame(GameInfo(654, Striptease, "Striptease",
-                      GI.GT_1DECK_TYPE, 1, 0, GI.SL_MOSTLY_SKILL))
+                      GI.GT_GOLF, 1, 0, GI.SL_MOSTLY_SKILL))
 registerGame(GameInfo(784, TakeAway8, "Take Away 8",
                       GI.GT_1DECK_TYPE | GI.GT_OPEN, 1, 0, GI.SL_MOSTLY_SKILL))
@@ -242,11 +242,11 @@ class TakeAway8(TakeAway):
 # register the game
 registerGame(GameInfo(334, TakeAway, "Take Away",
-                      GI.GT_1DECK_TYPE | GI.GT_OPEN, 1, 0, GI.SL_MOSTLY_SKILL,
+                      GI.GT_GOLF | GI.GT_OPEN, 1, 0, GI.SL_MOSTLY_SKILL,
                       altnames=("Eliminator", "Wolfpack", "Strip")))
 registerGame(GameInfo(335, FourStacks, "Four Stacks",
@@ -242,11 +242,11 @@ class TakeAway8(TakeAway):
 registerGame(GameInfo(784, TakeAway8, "Take Away 8",
-                      GI.GT_1DECK_TYPE | GI.GT_OPEN, 1, 0, GI.SL_MOSTLY_SKILL))
+                      GI.GT_GOLF | GI.GT_OPEN, 1, 0, GI.SL_MOSTLY_SKILL))